@@ -522,6 +522,16 @@ class GitObjectStorageContext(
             self._writeFile(
                 (itemPath / "comment.md").as_posix(), comment.encode()
             )
+        else:
+            try:
+                self._deleteFile(itemPath / "comment.md")
+            except (
+                KeyError,
+                OSError,
+            ):
+                # Saving an item where the comment did not exist
+                pass
+
         if script:
             self._writeFile(
                 (itemPath / "script.txt").as_posix(), script.encode()
